package trace

  1. Overview
  2. Docs

Module Trace_util.Multi_collectorSource

Combine multiple collectors into one

Combine multiple collectors, ie return a collector that forwards to every collector in the list.

combine s1 s2 is a collector that forwards every call to s1 and s2 both.